.. image:: images/ocelot-logo.png
    :align: center

Ocelot
======

The Ocelot project is a joint effort by the Paul Scherrer Institut and the ecoinvent centre to build an open source library for applying system models in life cycle assessment. See more information at https://ocelot.space/; the source code is `on Github <https://github.com/OcelotProject/Ocelot>`__.

.. warning:: Ocelot is under heavy development, and does not yet produce a complete database. See the `Ocelot milestones <https://github.com/OcelotProject/Ocelot/milestones>`__ to learn more about what is expected to be finished, and when.

Documentation
=============

Contents:

.. toctree::
   :maxdepth: 2

   installation
   cli
   data_format
   foundation
   tests
   contributing

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

